==> fsl_4.0.4.orig.tar.gz: fsl-4.0.4.orig/src/fabber/inference_vb.h <==
/*  inference_vb.h - VB inference technique class declarations

    Adrian Groves and Michael Chappell, FMRIB Image Analysis Group

    Copyright (C) 2007 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    http://www.fmrib.ox.ac.uk/fsl
    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    
    LICENCE
    
    FMRIB Software Library, Release 4.0 (c) 2007, The University of
    Oxford (the "Software")
    
    The Software remains the property of the University of Oxford ("the
    University").
    
    The Software is distributed "AS IS" under this Licence solely for
    non-commercial use in the hope that it will be useful, but in order
    that the University as a charitable foundation protects its assets for
    the benefit of its educational and research purposes, the University
    makes clear that no condition is made or to be implied, nor is any
    warranty given or to be implied, as to the accuracy of the Software,
    or that it will be suitable for any particular purpose or for use
    under any specific conditions. Furthermore, the University disclaims
    all responsibility for the use which is made of the Software. It
    further disclaims any liability for the outcomes arising from using
    the Software.
    
    The Licensee agrees to indemnify the University and hold the
    University harmless from and against any and all claims, damages and
    liabilities asserted by third parties (including claims for
    negligence) which arise directly or indirectly from the use of the
    Software or the sale of any products based on the Software.
    
    No part of the Software may be reproduced, modified, transmitted or
    transferred in any form or by any means, electronic or mechanical,
    without the express permission of the University. The permission of
    the University is not required if the said reproduction, modification,
    transmission or transference is done without financial return, the
    conditions of this Licence are imposed upon the receiver of the
    product, and all original and amended source code is included in any
    transmitted product. You may be held legally responsible for any
    copyright infringement that is caused or encouraged by your failure to
    abide by these terms and conditions.
    
    You are not permitted under this Licence to use this Software
    commercially. Use for which any financial return is received shall be
    defined as commercial use, and includes (1) integration of all or part
    of the source code or the Software into a product for sale or license
    by or on behalf of Licensee to third parties or (2) use of the
    Software or any derivative of it for research with the final aim of
    developing software products for sale or license to a third party or
    (3) use of the Software or any derivative of it for research with the
    final aim of developing non-software products for sale or license to a
    third party, or (4) use of the Software to provide any service to an
    external organisation for which payment is received. If you are
    interested in using the Software commercially, please contact Isis
    Innovation Limited ("Isis"), the technology transfer company of the
    University, to negotiate a licence. Contact details are:
    innovation@isis.ox.ac.uk quoting reference DE/1112. */

#pragma once
#include "inference.h"

// Subclasses defined here!
// The actual implementation details don't need to be visible to anyone else,
// since the appropriate derived class is returned by the global function
// PickInferenceTechnique(string).

// Forward declaration -- see convergence.h, which is only actually
// #included in inference_vb.cc.  For now it's good enough just to know
// that the class exists.
class ConvergenceDetector;

class VariationalBayesInferenceTechnique : public InferenceTechnique {
   public:
      VariationalBayesInferenceTechnique() 
            : conv(NULL), initialFwdPrior(NULL),
             initialFwdPosterior(NULL) { return; }
      virtual void Setup(ArgsType& args);
      //  virtual void SetOutputFilenames(ArgsType& args);
      virtual void DoCalculations(const DataSet& data);    
      virtual ~VariationalBayesInferenceTechnique();
   protected:
      ConvergenceDetector* conv;
      const MVNDist* initialFwdPrior;
      const MVNDist* initialFwdPosterior;
      
      bool haltOnBadVoxel;
      bool printF;
      bool needF;
};

==> fsl_4.1.9.orig.tar.gz: fsl-4.1.9.orig/src/fabber/inference_vb.h <==
/*  inference_vb.h - VB inference technique class declarations

    Adrian Groves and Michael Chappell, FMRIB Image Analysis Group

    Copyright (C) 2007 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    http://www.fmrib.ox.ac.uk/fsl
    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    
    LICENCE
    
    FMRIB Software Library, Release 4.0 (c) 2007, The University of
    Oxford (the "Software")
    
    The Software remains the property of the University of Oxford ("the
    University").
    
    The Software is distributed "AS IS" under this Licence solely for
    non-commercial use in the hope that it will be useful, but in order
    that the University as a charitable foundation protects its assets for
    the benefit of its educational and research purposes, the University
    makes clear that no condition is made or to be implied, nor is any
    warranty given or to be implied, as to the accuracy of the Software,
    or that it will be suitable for any particular purpose or for use
    under any specific conditions. Furthermore, the University disclaims
    all responsibility for the use which is made of the Software. It
    further disclaims any liability for the outcomes arising from using
    the Software.
    
    The Licensee agrees to indemnify the University and hold the
    University harmless from and against any and all claims, damages and
    liabilities asserted by third parties (including claims for
    negligence) which arise directly or indirectly from the use of the
    Software or the sale of any products based on the Software.
    
    No part of the Software may be reproduced, modified, transmitted or
    transferred in any form or by any means, electronic or mechanical,
    without the express permission of the University. The permission of
    the University is not required if the said reproduction, modification,
    transmission or transference is done without financial return, the
    conditions of this Licence are imposed upon the receiver of the
    product, and all original and amended source code is included in any
    transmitted product. You may be held legally responsible for any
    copyright infringement that is caused or encouraged by your failure to
    abide by these terms and conditions.
    
    You are not permitted under this Licence to use this Software
    commercially. Use for which any financial return is received shall be
    defined as commercial use, and includes (1) integration of all or part
    of the source code or the Software into a product for sale or license
    by or on behalf of Licensee to third parties or (2) use of the
    Software or any derivative of it for research with the final aim of
    developing software products for sale or license to a third party or
    (3) use of the Software or any derivative of it for research with the
    final aim of developing non-software products for sale or license to a
    third party, or (4) use of the Software to provide any service to an
    external organisation for which payment is received. If you are
    interested in using the Software commercially, please contact Isis
    Innovation Limited ("Isis"), the technology transfer company of the
    University, to negotiate a licence. Contact details are:
    innovation@isis.ox.ac.uk quoting reference DE/1112. */

#pragma once
#include "inference.h"

// Subclasses defined here!
// The actual implementation details don't need to be visible to anyone else,
// since the appropriate derived class is returned by the global function
// PickInferenceTechnique(string).

// Forward declaration -- see convergence.h, which is only actually
// #included in inference_vb.cc.  For now it's good enough just to know
// that the class exists.
class ConvergenceDetector;

class VariationalBayesInferenceTechnique : public InferenceTechnique {
   public:
      VariationalBayesInferenceTechnique() : conv(NULL), 
        initialFwdPrior(NULL), initialFwdPosterior(NULL), 
        initialNoisePrior(NULL), initialNoisePosterior(NULL) { return; }
      virtual void Setup(ArgsType& args);
      //  virtual void SetOutputFilenames(ArgsType& args);
      virtual void DoCalculations(const DataSet& data);    
      virtual ~VariationalBayesInferenceTechnique();
   protected:
      ConvergenceDetector* conv;
      const MVNDist* initialFwdPrior;
      const MVNDist* initialFwdPosterior;
      const NoiseParams* initialNoisePrior;
      const NoiseParams* initialNoisePosterior;
      
      // These are used for resuming a previous calculation
      string continueFromFile; // if empty, use initial posterior dists above
      bool continueFwdOnly; // Only have fwd-model information
      
      // Reduce this to a linear problem, using the given 
      // voxelwise linearizations (probably loaded from an MVN)
      string lockedLinearFile; 

      bool haltOnBadVoxel;
      bool printF;
      bool needF;
};
